#
# $Id: Repository.pm 138 2014-09-29 19:48:37Z gomor $
#
package Metabrik::Repository;
use strict;
use warnings;

our $VERSION = '1.00';

1;

__END__

=head1 NAME

Metabrik::Repository - main Metabrik repository

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret

You may distribute this module under the terms of The BSD 3-Clause License.
See LICENSE file in the source distribution archive.

=head1 AUTHOR

Patrice E<lt>GomoRE<gt> Auffret

=cut
